AdeptLog class

A lightweight, structured logger for Flutter and Dart.

Supports:

  • Debug, Info, Success and Error logs
  • Colored output in debug mode
  • JSON logging for Map & List
  • Optional tags for log categorization
  • Automatic caller detection

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

d(dynamic message, {String? tag}) → void
Logs a debug message.
e(dynamic message, {String? tag, StackTrace? stackTrace}) → void
Logs an error message.
i(dynamic message, {String? tag}) → void
Logs an informational message.
s(dynamic message, {String? tag}) → void
Logs a success message.